==> saga_2.1.2+dfsg.orig.tar.gz: saga-2.1.2/src/modules/io/io_shapes/generate.cpp <==
/**********************************************************
 * Version $Id: generate.cpp 1921 2014-01-09 10:24:11Z oconrad $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                       Shapes_IO                       //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                     Generate.cpp                      //
//                                                       //
//                 Copyright (C) 2003 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Goettingen               //
//                Goldschmidtstr. 5                      //
//                37077 Goettingen                       //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#include "generate.h"


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
CGenerate_Export::CGenerate_Export(void)
{
	CSG_Parameter	*pNode;

	Set_Name(_TL("Export Shapes to Generate"));

	Set_Author		(SG_T("(c) 2003 by O.Conrad"));

	Set_Description	(_TW("Export generate shapes format."));

	pNode	= Parameters.Add_Shapes(
		NULL	, "SHAPES"	, _TL("Shapes"),
		_TL(""),
		PARAMETER_INPUT
	);

	Parameters.Add_Table_Field(
		pNode	, "FIELD"	, _TL("Attribute"),
		_TL("")
	);

	Parameters.Add_FilePath(
		NULL	, "FILENAME", _TL("File"),
		_TL("")
	);
}

//---------------------------------------------------------
CGenerate_Export::~CGenerate_Export(void)
{}


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
bool CGenerate_Export::On_Execute(void)
{
	int			iShape, iPart, iPoint, iField;
	FILE		*aus;
	TSG_Point	Point;
	CSG_Shape	*pShape;
	CSG_Shapes	*pLayer;
	CSG_String	fName;

	fName	= Parameters("FILENAME")->asString();

	if(	(pLayer = Parameters("SHAPES")->asShapes()) != NULL )
	{
		if( (aus = fopen(fName.b_str(), "w")) != NULL )
		{
			if( pLayer->Get_Field_Count() > 0 )
			{
				iField	= Parameters("FIELD")->asInt();

				if( pLayer->Get_Field_Type(iField) == SG_DATATYPE_String )
				{
					iField	= -1;
				}

				fprintf(aus, "EXP %s\nARC ", pLayer->Get_Name());

				for(iShape=0; iShape<pLayer->Get_Count() && Set_Progress(iShape, pLayer->Get_Count()); iShape++)
				{
					pShape	= pLayer->Get_Shape(iShape);

					for(iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
					{
						// Value...
						if( iField < 0 )
						{
							fprintf(aus, "%d ", iShape + 1);
						}
						else
						{
							fprintf(aus, "%lf ", pShape->asDouble(iField));
						}

						// dummy_I dummy_I dummy_I dummy_I dummy_I...
						fprintf(aus, "1 2 3 4 5 ");
						// I_np...
						fprintf(aus, "%d ", pShape->Get_Point_Count(iPart));

						for(iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
						{
							Point	= pShape->Get_Point(iPoint, iPart);

							fprintf(aus, "%f %f ", Point.x, Point.y);
						}
					}
				}
			}

			fclose(aus);

			return( true );
		}
	}

	return( false );
}

==> saga_2.3.1+dfsg.orig.tar.gz: saga-2.3.1/src/modules/io/io_shapes/generate.cpp <==
/**********************************************************
 * Version $Id: generate.cpp 1921 2014-01-09 10:24:11Z oconrad $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                       Shapes_IO                       //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                     Generate.cpp                      //
//                                                       //
//                 Copyright (C) 2003 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Goettingen               //
//                Goldschmidtstr. 5                      //
//                37077 Goettingen                       //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#include "generate.h"


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
CGenerate_Export::CGenerate_Export(void)
{
	Set_Name		(_TL("Export Shapes to Generate"));

	Set_Author		("O.Conrad (c) 2003");

	Set_Description	(_TW(
		"Export generate shapes format."
	));

	CSG_Parameter	*pNode	= Parameters.Add_Shapes(
		NULL	, "SHAPES"	, _TL("Shapes"),
		_TL(""),
		PARAMETER_INPUT
	);

	Parameters.Add_Table_Field(
		pNode	, "FIELD"	, _TL("Attribute"),
		_TL("")
	);

	Parameters.Add_FilePath(
		NULL	, "FILE"	, _TL("File"),
		_TL("")
	);
}


///////////////////////////////////////////////////////////
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
bool CGenerate_Export::On_Execute(void)
{
	//-----------------------------------------------------
	CSG_File	Stream;

	if( !Stream.Open(Parameters("FILE")->asString(), SG_FILE_W) )
	{
		return( false );
	}

	CSG_Shapes	*pShapes	= Parameters("SHAPES")->asShapes();

	if( !pShapes->is_Valid() || pShapes->Get_Count() <= 0 )
	{
		return( false );
	}

	//-----------------------------------------------------
	int	iField	= Parameters("FIELD")->asInt();

	if( pShapes->Get_Field_Type(iField) == SG_DATATYPE_String )
	{
		iField	= -1;
	}

	Stream.Printf(SG_T("EXP %s\nARC "), pShapes->Get_Name());

	//-----------------------------------------------------
	for(int iShape=0; iShape<pShapes->Get_Count() && Set_Progress(iShape, pShapes->Get_Count()); iShape++)
	{
		CSG_Shape	*pShape	= pShapes->Get_Shape(iShape);

		for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
		{
			if( iField < 0 )	// Value...
			{
				Stream.Printf(SG_T("%d "), iShape + 1);
			}
			else
			{
				Stream.Printf(SG_T("%lf "), pShape->asDouble(iField));
			}

			Stream.Printf(SG_T("1 2 3 4 5 "));	// dummy_I dummy_I dummy_I dummy_I dummy_I...
			Stream.Printf(SG_T("%d "), pShape->Get_Point_Count(iPart));	// I_np...

			for(int iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
			{
				TSG_Point	p	= pShape->Get_Point(iPoint, iPart);

				Stream.Printf(SG_T("%f %f "), p.x, p.y);
			}
		}
	}

	//-----------------------------------------------------
	return( true );
}


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
